@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef KSELFILTERPAGE_H
-#define KSELFILTERPAGE_H
+#ifndef MANUALSELECTFILTERPAGE_H
+#define MANUALSELECTFILTERPAGE_H
 
 #include "ui_manualselectfilterpage.h"
 #include <QList>
@@ -41,7 +41,7 @@ private Q_SLOTS:
     void filterSelected(int i);
 
 private:
-    Ui::ManualSelectFilterPage *mWidget;
+    Ui::ManualSelectFilterPage *mWidget = nullptr;
     QList<MailImporter::Filter *> mFilterList;
 };
 
